@@ -1052,7 +1052,7 @@ namespace std
 #define _GLIBCXX_HAVE_SYS_RESOURCE_H 1
 
 /* Define to 1 if you have a suitable <sys/sdt.h> header file */
-/* #undef _GLIBCXX_HAVE_SYS_SDT_H */
+#define _GLIBCXX_HAVE_SYS_SDT_H 1
 
 /* Define to 1 if you have the <sys/sem.h> header file. */
 #define _GLIBCXX_HAVE_SYS_SEM_H 1
